@@ -3,9 +3,14 @@ import warnings
 import re
 import itertools
 from enum import Enum
-from typing import Optional
+from typing import Optional, TYPE_CHECKING
 
 from pydantic import Field
+from pydantic.fields import FieldInfo
+
+if TYPE_CHECKING:  # pragma: no cover
+    from typing import Any
+
 
 _PYDANTIC_FIELD_KWARGS = list(inspect.signature(Field).parameters.keys())
 
@@ -17,6 +22,9 @@ __all__ = (
     "SupportLevel",
 )
 
+OPTIMADE_SCHEMA_EXTENSION_KEYS = ["support", "queryable", "unit", "sortable"]
+OPTIMADE_SCHEMA_EXTENSION_PREFIX = "x-optimade-"
+
 
 class SupportLevel(Enum):
     """OPTIMADE property/field support levels"""
@@ -26,11 +34,35 @@ class SupportLevel(Enum):
     OPTIONAL = "optional"
 
 
+class StrictFieldInfo(FieldInfo):
+    """Wraps the standard pydantic `FieldInfo` in order
+    to prefix any custom keys from `StrictField`.
+
+    """
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        for key in OPTIMADE_SCHEMA_EXTENSION_KEYS:
+            if key in self.extra:
+                self.extra[f"{OPTIMADE_SCHEMA_EXTENSION_PREFIX}{key}"] = self.extra.pop(
+                    key
+                )
+
+
+def StrictPydanticField(*args, **kwargs):
+    """Wrapper for `Field` that uses `StrictFieldInfo` instead of
+    the pydantic `FieldInfo`.
+    """
+    field_info = StrictFieldInfo(*args, **kwargs)
+    field_info._validate()
+    return field_info
+
+
 def StrictField(
-    *args,
+    *args: "Any",
     description: str = None,
-    **kwargs,
-) -> Field:
+    **kwargs: "Any",
+) -> StrictFieldInfo:
     """A wrapper around `pydantic.Field` that does the following:
 
     - Forbids any "extra" keys that would be passed to `pydantic.Field`,
@@ -56,13 +88,10 @@ def StrictField(
     """
 
     allowed_keys = [
-        "unit",
         "pattern",
         "uniqueItems",
-        "support",
-        "queryable",
-        "sortable",
-    ]
+        "nullable",
+    ] + OPTIMADE_SCHEMA_EXTENSION_KEYS
     _banned = [k for k in kwargs if k not in set(_PYDANTIC_FIELD_KWARGS + allowed_keys)]
 
     if _banned:
@@ -78,7 +107,7 @@ def StrictField(
             f"No description provided for StrictField specified by {args}, {kwargs}."
         )
 
-    return Field(*args, **kwargs)
+    return StrictPydanticField(*args, **kwargs)
 
 
 def OptimadeField(
@@ -139,7 +168,7 @@ class SemanticVersion(str):
     def __modify_schema__(cls, field_schema):
         field_schema.update(
             pattern=cls.regex.pattern,
-            examples=["0.10.1", "1.0.0-rc.2", "1.2.3-rc.5+develop"],
+            example=["0.10.1", "1.0.0-rc.2", "1.2.3-rc.5+develop"],
         )
 
     @classmethod
